@@ -1,4 +1,4 @@
-/* $Id: dom.c,v 1.50 2002/11/13 15:15:15 matt Exp $ */
+/* $Id: dom.c,v 1.53 2003/06/23 19:37:17 phish Exp $ */
 #include <libxml/tree.h>
 #include <libxml/encoding.h>
 #include <libxml/xmlerror.h>
@@ -8,7 +8,7 @@
 #include <libxml/xmlIO.h>
 #include <libxml/xpath.h>
 #include <libxml/xpathInternals.h>
-
+#include <libxml/globals.h>
 #include <stdio.h>
 
 #define warn(string) fprintf(stderr, string) 
@@ -184,12 +184,15 @@ domAddNodeToList(xmlNodePtr cur, xmlNodePtr leader, xmlNodePtr followup)
    xmlNodePtr c1 = NULL, c2 = NULL, p = NULL;
    if ( cur ) { 
        c1 = c2 = cur;
-       if( leader )
+       if( leader ) {
           p = leader->parent;
-       else if( followup ) 
+       }
+       else if( followup ) {
           p = followup->parent;
-       else
-          return(0); /* can't insert */
+       }
+       else {
+          return 0; /* can't insert */
+       }
 
        if ( cur->type == XML_DOCUMENT_FRAG_NODE ) {
            c1 = cur->children;
@@ -205,7 +208,7 @@ domAddNodeToList(xmlNodePtr cur, xmlNodePtr leader, xmlNodePtr followup)
            cur->parent = p;
        }
        
-       if (c1 && c2 && c1!=leader) {
+       if (c1 && 2 && c1!=leader) {
            if ( leader ) {
                leader->next = c1;
 	       c1->prev = leader;
@@ -381,17 +384,67 @@ domImportNode( xmlDocPtr doc, xmlNodePtr node, int move ) {
  **/
 xmlChar*
 domName(xmlNodePtr node) {
-    xmlChar *qname = NULL; 
-    if ( node ) {
-        if (node->ns != NULL && node->ns->prefix != NULL) {
-            xmlChar *tname = xmlStrdup( node->ns->prefix );
-            tname = xmlStrcat( tname , (const xmlChar *) ":" );
-            tname = xmlStrcat( tname , node->name );
-            qname = tname;
-        } 
-        else {
-            qname = xmlStrdup( node->name );
+    const xmlChar *prefix = NULL;
+    const xmlChar *name   = NULL;
+    xmlChar *qname        = NULL; 
+    
+    if ( node == NULL ) {
+        return NULL;
+    }
+
+    switch ( node->type ) {
+    case XML_TEXT_NODE :
+    case XML_COMMENT_NODE :
+    case XML_CDATA_SECTION_NODE :
+    case XML_XINCLUDE_START :
+    case XML_XINCLUDE_END :
+    case XML_ENTITY_REF_NODE :
+    case XML_ENTITY_NODE :
+    case XML_DTD_NODE :
+    case XML_ENTITY_DECL :
+    case XML_DOCUMENT_TYPE_NODE :
+    case XML_PI_NODE :
+    case XML_NOTATION_NODE :
+    case XML_NAMESPACE_DECL :
+        name = node->name;
+        break;
+
+    case XML_DOCUMENT_NODE :
+    case XML_HTML_DOCUMENT_NODE :
+    case XML_DOCB_DOCUMENT_NODE :
+        name = "document";
+        break;
+
+    case XML_DOCUMENT_FRAG_NODE :
+        name = "document_fragment";
+        break;
+
+    case XML_ELEMENT_NODE :
+    case XML_ATTRIBUTE_NODE :
+        if ( node->ns != NULL ) {
+            prefix = node->ns->prefix;
         }
+        name = node->name;
+        break;
+
+    case XML_ELEMENT_DECL :
+        prefix = ((xmlElementPtr) node)->prefix;
+        name = node->name;
+        break;
+
+    case XML_ATTRIBUTE_DECL :
+        prefix = ((xmlAttributePtr) node)->prefix;
+        name = node->name;
+        break;
+    }
+
+    if ( prefix != NULL ) {
+        qname = xmlStrdup( prefix );
+        qname = xmlStrcat( qname , (const xmlChar *) ":" );
+        qname = xmlStrcat( qname , name );
+    } 
+    else {
+        qname = xmlStrdup( node->name );
     }
 
     return qname;
@@ -464,13 +517,19 @@ domAppendChild( xmlNodePtr self,
 
 xmlNodePtr
 domRemoveChild( xmlNodePtr self, xmlNodePtr old ) {
-    if ( self  
-         && old 
-	 && old->type != XML_ATTRIBUTE_NODE
-	 && old->type != XML_NAMESPACE_DECL
-         && (self == old->parent)) {
-        domUnlinkNode( old );
+    if ( self == NULL || old == NULL ) {
+        return NULL;
     }
+    if ( old->type == XML_ATTRIBUTE_NODE
+         || old->type == XML_NAMESPACE_DECL ) {
+        return NULL;
+    }
+    if ( self != old->parent ) {
+        /* not a child! */
+        return NULL;
+    }
+
+    domUnlinkNode( old );    
     return old ;
 }
 
@@ -511,6 +570,11 @@ domReplaceChild( xmlNodePtr self, xmlNodePtr new, xmlNodePtr old ) {
         domRemoveChild( self, old );
         domAppendChild( self, new );
     }
+    else if ( new->type == XML_DOCUMENT_FRAG_NODE 
+              && new->children == NULL ) {
+        /* want to replace with an empty fragment, then remove ... */
+        domRemoveChild( self, old );
+    }
     else {
         domAddNodeToList(new, old->prev, old->next );
         old->parent = old->next = old->prev = NULL;    
@@ -524,24 +588,23 @@ xmlNodePtr
 domInsertBefore( xmlNodePtr self, 
                  xmlNodePtr newChild,
                  xmlNodePtr refChild ){
-
-    if ( refChild == newChild ) 
+    if ( refChild == newChild ) {
         return newChild;
-    
-    if ( self == NULL || newChild == NULL ) 
-        return NULL;
-   
-    if ( refChild == NULL ) {
-        refChild = self->children;
     }
-
-    if ( refChild->parent != self
-       || (  newChild->type     == XML_DOCUMENT_FRAG_NODE 
-          && newChild->children == NULL ) ) {
-        /* NOT_FOUND_ERR */
-        xmlGenericError(xmlGenericErrorContext,"NOT_FOUND_ERR\n");
+    
+    if ( self == NULL || newChild == NULL ) {
         return NULL;
     }
+   
+    if ( refChild != NULL ) {
+        if ( refChild->parent != self
+             || (  newChild->type     == XML_DOCUMENT_FRAG_NODE 
+                   && newChild->children == NULL ) ) {
+            /* NOT_FOUND_ERR */
+            xmlGenericError(xmlGenericErrorContext,"NOT_FOUND_ERR\n");
+            return NULL;
+        }
+    }
 
     if ( !(domTestHierarchy( self, newChild )
            && domTestDocument( self, newChild ))) {
@@ -556,7 +619,13 @@ domInsertBefore( xmlNodePtr self,
         newChild = domImportNode( self->doc, newChild, 1 );
     }
     
-    domAddNodeToList(newChild, refChild->prev, refChild);
+    if ( refChild == NULL ) {
+        domAddNodeToList(newChild, self->last, NULL);
+    }
+    else { 
+        domAddNodeToList(newChild, refChild->prev, refChild);
+    }
+
     if ( newChild->type != XML_ENTITY_REF_NODE ) {
         xmlReconciliateNs(self->doc, newChild);     
     }
@@ -571,42 +640,10 @@ xmlNodePtr
 domInsertAfter( xmlNodePtr self, 
                 xmlNodePtr newChild,
                 xmlNodePtr refChild ){
-    if ( self == NULL || newChild == NULL ) 
-        return NULL;
-
-    if ( refChild == newChild ) 
-        return newChild;
-    
     if ( refChild == NULL ) {
-        return domAppendChild( self, newChild );
+        return domInsertBefore( self, newChild, NULL );
     }
-
-    if ( refChild->parent != self
-       || (  newChild->type     == XML_DOCUMENT_FRAG_NODE 
-          && newChild->children == NULL ) ) {
-        xmlGenericError(xmlGenericErrorContext,"NOT_FOUND_ERR\n");
-        return NULL;
-    }
-
-    if ( !(domTestHierarchy( self, newChild )
-           && domTestDocument( self, newChild ))) {
-        xmlGenericError(xmlGenericErrorContext,"HIERARCHIY_REQUEST_ERR\n");
-        return NULL;
-    }
-
-    if ( self->doc == newChild->doc ){
-        domUnlinkNode( newChild );
-    }
-    else {
-        newChild = domImportNode( self->doc, newChild, 1 );
-    }
-
-    domAddNodeToList(newChild, refChild, refChild->next);
-    if ( newChild->type != XML_ENTITY_REF_NODE ) {
-        xmlReconciliateNs(self->doc, newChild);     
-    }
-
-    return newChild;
+    return domInsertBefore( self, newChild, refChild->next );
 }
 
 xmlNodePtr
