@@ -39,8 +39,6 @@ unless ( $targetdir =~ /\/$/ ) {
 # ------------------------------------------------------------------------- #
 # init the parser
 my $parser = XML::LibXML->new();
-$parser->load_ext_dtd(0);
-$parser->keep_blanks(0);
 # ------------------------------------------------------------------------- #
 #
 # ------------------------------------------------------------------------- #
@@ -73,7 +71,6 @@ foreach my $chap ( @chapters ) {
 # the class to process our dokbook file
 # ------------------------------------------------------------------------- #
 package ChapterHandler;
-use XML::LibXML;
 
 # ------------------------------------------------------------------------- #
 # the constructor
@@ -118,7 +115,7 @@ sub set_general_info {
 
     my ( $version ) = $infonode->findnodes( "edition" );
     if ( defined $version ) {
-        $infostr .= "\n=head1 VERSION\n\n" . $version->string_value() . "\n\n";
+        $infostr .= "=head1 VERSION\n\n" . $version->string_value() . "\n\n";
     }
 
     my ( $copyright ) = $infonode->findnodes( "copyright" );
@@ -132,7 +129,7 @@ sub set_general_info {
         if ( defined $node_h ) {
             $infostr .= $node_h->string_value();
         }
-        $infostr .= ".\n\n=cut\n"
+        $infostr .= ", All rights reserved.\n\n=cut\n"
     }
 
     $self->{infoblock} = $infostr;
@@ -216,6 +213,8 @@ sub dump_text {
         if ( $node->nodeName() eq "para" ) {
             # we split at the last whitespace before 80 chars
             my $string = $node->string_value();
+            $string =~ s/^\s*|\s*$//g;
+
             my $os = "";
             my @words = split /\s+/, $string;
             foreach my $word ( @words ) {
@@ -299,66 +298,45 @@ sub dump_pod {
         my ( $title ) = $chap->getChildrenByTagName( "title" );
         my ( $ttlabbr ) = $chap->getChildrenByTagName( "titleabbrev" );
         my $str =  $ttlabbr->string_value() . " - ".$title->string_value();
-	$str=~s/^\s+|\s+$//g;
-        $self->{OFILE}->print(  "=head1 NAME\n\n$str\n" );
-	my ($synopsis) = $chap->findnodes( "sect1[title='Synopsis']" );
+        $self->{OFILE}->print(  "=head1 NAME\n\n$str\n\n" );
         my @funcs = $chap->findnodes( ".//funcsynopsis" );
-	if ($synopsis or scalar @funcs) {
-            $self->{OFILE}->print( "\n=head1 SYNOPSIS\n\n" )
-	}
-	if ($synopsis) {
-	  $self->dump_pod( $synopsis );
-	}
         if ( scalar @funcs ) {
+            $self->{OFILE}->print( "=head1 SYNOPSIS\n\n" );
             foreach my $s ( @funcs ) {
                 $self->dump_pod( $s );
             }
-            # $self->{OFILE}->print( "\n\n=head1 DESCRIPTION\n\n" );
+            $self->{OFILE}->print( "\n\n=head1 DESCRIPTION\n\n" );
         }
     }
 
     foreach my $node ( $chap->childNodes() ) {
-      if ( $node->nodeType == XML_TEXT_NODE ||
-	     $node->nodeType == XML_CDATA_SECTION_NODE ) {
- 	# we split at the last whitespace before 80 chars
-	my $prev_inline =
-	  ($node->previousSibling and
-	   $node->previousSibling->nodeName !~
-	     /^(?:itemizedlist|orderedlist|variablelist|programlisting|funcsynopsis)/)
-	    ? 1 : 0;
-	my $str = $node->data();
-	$str=~s/(^|\n)[ \t]+($|\n)/$1$2/g;
-	if ($str=~/\S/) {
-	  my $string = $str;
-	  my $space_before = ($string =~ s/^\s+//g) ? $prev_inline : 0;
-	  my $space_after = ($string =~ s/\s+$//g) ? 1 : 0;
-	  $self->{OFILE}->print( " " ) if $space_before;
-	  my $os = "";
-	  my @words = split /\s+/, $string;
-	  foreach my $word ( @words ) {
-	    if ( (length( $os ) + length( $word ) + 1) < 80 ) {
-	      if ( length $os ) { $os .= " "; }
-	    $os .= $word;
-	    }
-	    else {
-	      $self->{OFILE}->print( $os . "\n" );
-	      $os = $word;
-	    }
-	  }
-	  $os.=" " if $space_after;
-	  $self->{OFILE}->print( $os );
-	}
-      } elsif ( $node->nodeName() eq "para" ) {
-	$self->dump_pod( $node );
-	$self->{OFILE}->print( "\n\n" );
-      } elsif ( $node->nodeName() eq "sect1" ) {
+        if ( $node->nodeName() eq "para" ) {
+            # we split at the last whitespace before 80 chars
+            my $string = $node->string_value();
+            $string =~ s/^\s*|\s*$//g;
+
+            my $os = "";
+            my @words = split /\s+/, $string;
+            foreach my $word ( @words ) {
+                if ( (length( $os ) + length( $word ) + 1) < 80 ) {
+                    if ( length $os ) { $os .= " "; }
+                    $os .= $word;
+                }
+                else {
+                    $self->{OFILE}->print( $os . "\n" );
+                    $os = $word;
+                }
+            }
+            $self->{OFILE}->print( $os );
+            $self->{OFILE}->print( "\n\n" );
+        }
+        elsif ( $node->nodeName() eq "sect1" ) {
             my ( $title ) = $node->getChildrenByTagName( "title" );
-	    my $str = $title->string_value();
-	    unless ($chap->nodeName eq "chapter" and $str eq 'Synopsis') {
-	      $self->{OFILE}->print( "\n=head1 " . uc($str) );
-	      $self->{OFILE}->print( "\n\n" );
-	      $self->dump_pod( $node );
-	    }
+            my $str = $title->string_value();
+
+            $self->{OFILE}->print( "\n=head1 " . uc($str) );
+            $self->{OFILE}->print( "\n\n" );
+            $self->dump_pod( $node );
         }
         elsif (  $node->nodeName() eq "sect2" ) {
             my ( $title ) = $node->getChildrenByTagName( "title" );
@@ -369,21 +347,14 @@ sub dump_pod {
 
             $self->dump_pod( $node );
         }
-        elsif (  $node->nodeName() eq "sect3" ) {
-            my ( $title ) = $node->getChildrenByTagName( "title" );
-            my $str = $title->string_value();
-            my $len = length $str;
-
-            $self->{OFILE}->print( "\n=head3 " . $str . "\n\n" );
-
-            $self->dump_pod( $node );
-        }
         elsif ( $node->nodeName() eq "itemizedlist" ) {
             my @items = $node->findnodes( "listitem" );
+            my $sp= "  ";
             $self->{OFILE}->print( "\n=over 4\n\n" );
             foreach my $item ( @items ) {
-                $self->{OFILE}->print( "=item *\n\n" );
-		$self->dump_pod( $item );
+                my $str = $item->string_value();
+                $str =~ s/^\s*|\s*$//g;
+                $self->{OFILE}->print( "=item * ".$str );
                 $self->{OFILE}->print( "\n\n" );
             }
             $self->{OFILE}->print( "=back\n\n" );
@@ -391,12 +362,16 @@ sub dump_pod {
         elsif ( $node->nodeName() eq "orderedlist" ) {
             my @items = $node->findnodes( "listitem" );
             my $i = 0;
-            $self->{OFILE}->print( "\n=over 4\n\n" );
+            my $sp= "  ";
+
+            $self->{OFILE}->print( "=over 4\n\n" );
 
             foreach my $item ( @items ) {
                 $i++;
-                $self->{OFILE}->print( "=item $i.\n\n" );
-		$self->dump_pod($item);
+                $self->{OFILE}->print( "=item $i " );
+                my $str = $item->string_value();
+                $str =~ s/^\s*|\s*$//g;
+                $self->{OFILE}->print( $str );
                 $self->{OFILE}->print( "\n\n" );
             }
             $self->{OFILE}->print( "=back\n\n" );
@@ -411,7 +386,7 @@ sub dump_pod {
             my ( $term ) = $node->findnodes( "term" );
             $self->{OFILE}->print( "=item " );
             if ( defined $term ) {
-	      $self->dump_pod( $term );
+                $self->{OFILE}->print( "B<".$term->string_value().">" );
             }
             $self->{OFILE}->print( "\n\n" );
             my @nodes =$node->findnodes( "listitem" );
@@ -422,10 +397,7 @@ sub dump_pod {
         }
         elsif ( $node->nodeName() eq "programlisting" ) {
             my $str = $node->string_value();
-	    $str =~ s/^\s+|\s+$//g;
             $str =~ s/\n/\n  /g;
-	    $str=~s/(^|\n)[ \t]+($|\n)/$1$2/g;
-            $self->{OFILE}->print( "\n\n" );
             $self->{OFILE}->print( "  ". $str );
             $self->{OFILE}->print( "\n\n" );
         }
@@ -437,58 +409,8 @@ sub dump_pod {
             my $str = $node->string_value() ;
             $str =~ s/\n/\n  /g;
             $self->{OFILE}->print( "  $str\n" );
-        } elsif(  $node->nodeName() eq "title" or
-		  $node->nodeName() eq "titleabbrev"
-		 ) {
-	  # IGNORE
-        } elsif(  $node->nodeName() eq "emphasis" ) {
-            my $str = $node->string_value() ;
-            $str =~ s/\n/ /g;
-            $self->{OFILE}->print( "I<<<<<< $str >>>>>>" );
-        } elsif(  $node->nodeName() eq "function" or
-		  $node->nodeName() eq "email" or
-		  $node->nodeName() eq "literal"
-	       ) {
-            my $str = $node->string_value() ;
-            $str =~ s/\n/ /g;
-            $self->{OFILE}->print( "C<<<<<< $str >>>>>>" );
-        } elsif(  $node->nodeName() eq "ulink" ) {
-            my $str = $node->string_value() ;
-	    my $url = $node->getAttribute('url');
-            $str =~ s/\n/ /g;
-	    if ($str eq $url) {
-	      $self->{OFILE}->print( "L<<<<<< $url >>>>>>" );
-	    } else {
-	      $self->{OFILE}->print( "$str (L<<<<<< $url >>>>>>)" );
-	    }
-        } elsif(  $node->nodeName() eq "xref" ) {
-	    my $linkend = $node->getAttribute('linkend');
-	    my ($target) = $node->findnodes(qq(//*[\@id="$linkend"]/titleabbrev));
-	    ($target) = $node->findnodes(qq(//*[\@id="$linkend"]/title)) unless $target;
-	    if ($target) {
-	      my $str = $target->string_value() ;
-	      $str =~ s/\n/ /g;
-	      $self->{OFILE}->print( "L<<<<<< $str >>>>>>" );
-	    } else {
-	      warn "WARNING: Didn't find any section with id='$linkend'\n";
-	      $self->{OFILE}->print( "$linkend" );
-	    }
-        } elsif(  $node->nodeName() eq "olink" ) {
-            my $str = $node->string_value() ;
-	    my $url = $node->getAttribute('targetdoc');
-	    if (!defined $url) {
-	      warn $node->toString(1),"\n";
-	    }
-            $str =~ s/\n/ /g;
-	    if ($str eq $url) {
-	      $self->{OFILE}->print( "L<<<<<< $url >>>>>>" );
-	    } else {
-	      $self->{OFILE}->print( "$str (L<<<<<< $url >>>>>>)" );
-	    }
-        } else {
-	  print STDERR "Ignoring ",$node->nodeName(),"\n";
-	  $self->dump_pod($node);
-	}
+
+        }
     }
 }
 
